Index: kernel/generic/src/ipc/sysipc.c
===================================================================
--- kernel/generic/src/ipc/sysipc.c	(revision 62ca560dd1468a2f5b122d9ee3473a376d048bae)
+++ kernel/generic/src/ipc/sysipc.c	(revision 7565a4b969469fdb7178a8e1f8f2feec7ee7cc64)
@@ -728,11 +728,7 @@
 		return ENOENT;
 	
-	if (ipc_phone_hangup(kobj->phone)) {
-		kobject_put(kobj);
-		return -1;
-	}
-	
+	int rc = ipc_phone_hangup(kobj->phone);
 	kobject_put(kobj);
-	return 0;
+	return rc;
 }
 

Index: kernel/generic/src/ipc/ipc.c
===================================================================
--- kernel/generic/src/ipc/ipc.c	(revision 62ca560dd1468a2f5b122d9ee3473a376d048bae)
+++ kernel/generic/src/ipc/ipc.c	(revision 7565a4b969469fdb7178a8e1f8f2feec7ee7cc64)
@@ -444,6 +444,6 @@
  * @param phone Phone structure to be hung up.
  *
  * @return 0 if the phone is disconnected.
  * @return -1 if the phone was already disconnected.
  *
  */
@@ -455,5 +455,5 @@
 	    phone->state == IPC_PHONE_CONNECTING) {
 		mutex_unlock(&phone->lock);
-		return -1;
+		return EINVAL;
 	}
 	
@@ -478,5 +478,5 @@
 	mutex_unlock(&phone->lock);
 	
-	return 0;
+	return EOK;
 }
 
@@ -444,6 +444,6 @@
  * @param phone Phone structure to be hung up.
  *
- * @return 0 if the phone is disconnected.
- * @return -1 if the phone was already disconnected.
+ * @return EOK if the phone is disconnected.
+ * @return EINVAL if the phone was already disconnected.
  *
  */